@@ -144,6 +144,7 @@ extern int
 push_gif(
 #ifdef USE_PROTOTYPES
         byte *,
+        int,
         int
 #endif
 );
@@ -175,6 +176,13 @@ extern byte
 #endif
 );
 
+extern void
+read_gif_extension( 
+#ifdef USE_PROTOTYPES
+        FILE *
+#endif
+);
+
 extern byte
 *unblock(
 #ifdef USE_PROTOTYPES
@@ -221,6 +229,15 @@ write_gif_cmap(
 #endif
 );
 
+extern int
+write_gif_graphics_ctrl_ext(
+#ifdef USE_PROTOTYPES
+        FILE *,
+        bitmap_hdr *,
+        int
+#endif
+);
+
 extern int
 write_gif_image_hdr(
 #ifdef USE_PROTOTYPES
@@ -229,6 +246,11 @@ write_gif_image_hdr(
 #endif
 );
 
+extern void
+set_write_gif89_flag();
+
+extern void
+unset_write_gif89_flag();
 
 /* heightfield.c */
 
